local menuButtons

do
	local loadButtons = function(...)
		menuButtons = {}
		for i = 1, select('#', ...) do
			local b = select(i, ...)
			local name = b:GetName()
			if not menuButtons[i] then
				table.insert(menuButtons, b)
			end
		end
	end
	loadButtons(VehicleSeatIndicator)
end

--[[ Minimap ]]--

local DMAP = Dominos:NewModule('VSI')
local MAP  = Dominos:CreateClass('Frame', Dominos.Frame)

function DMAP:Load()
	self.frame = MAP:New()
	self.frame:SetFrameStrata('MEDIUM')
end

function DMAP:Unload()
	self.frame:Free()
end

function MAP:New()
	local f = self.super.New(self, 'vsi')
	if not f.value then
		f:SetFrameStrata('DIALOG')
		for i = 1, #menuButtons do
			f:LoadButtons()
		end
	end
	f:Layout()
	VehicleSeatIndicator:SetScript("OnShow", function(self)
		self:ClearAllPoints()
		self:SetPoint("Center", f)
	end)
	VehicleSeatIndicator:HookScript("OnEvent", function(self)
		self:ClearAllPoints()
		self:SetPoint("Center", f)
	end)
	return f
end

function MAP:GetDefaults()
	return {
		scale = 1,
		point = 'TopRight',
		y = -175,
		x = 0,
	}
end

function MAP:NumButtons()
	return #menuButtons
end

function MAP:AddButton(i)
	local b = menuButtons[i]
	if b then
		b:SetParent(self.header)
		b:Show()
		b:EnableMouse(false)
		self.buttons[i] = b
	end
end

function MAP:RemoveButton(i)
	local b = self.buttons[i]
	if b then
		b:SetParent(nil)
		b:Hide()
		self.buttons[i] = nil
	end
end

local function AddLayoutPanel(menu)
	local p = menu:NewPanel(LibStub('AceLocale-3.0'):GetLocale('Dominos-Config').Layout)
	p:NewOpacitySlider()
	p:NewFadeSlider()
	p:NewScaleSlider()
	p:NewPaddingSlider()	
end

function MAP:CreateMenu()
	local menu = Dominos:NewMenu(self.id)
	AddLayoutPanel(menu)
	self.menu = menu
end
